@@ -1,5 +1,7 @@
 from enum import Enum
 
+WEB_PROC = "web"
+
 class Machine(Enum):
         lean = (256, 512)
         lean_x2 = (256, 1024)
@@ -14,9 +16,12 @@ class Proc:
         self.machine = kwargs.get("machine", Machine.lean)
         self.instances = kwargs.get("instances", 1)
         self.target_group = kwargs.get("target_group")
+        self.log_group = kwargs.get("log_group")
         self.port = kwargs.get("port", 8080)
         self.entry = kwargs["entry"]
         self.image = kwargs["image"]
+        if self.name == WEB_PROC and self.target_group is None:
+            raise ValueError("A web proc must have the target group specified")
 
 class ProcSet:
     def __init__(self, ** kwargs):
@@ -25,7 +30,6 @@ class ProcSet:
         self.subnet_a = kwargs["subnet_a"]
         self.subnet_b = kwargs["subnet_b"]
         self.role = kwargs["role"]
-        self.secret = kwargs.get("secret")
         self.procs = dict()
 
     def add_proc(self, proc):
